#!/bin/sh

convert_xpm_to_png()
{
	convert $1 $2.gif
	giftrans -t#000000 $2.gif > $2.gif2
	convert $2.gif2 $2.png
}

convert_xpm_to_png images/shutdown.xpm asui_icon
convert_xpm_to_png images/reboot.xpm asui_settings_icon

rm -f asui_icon.gif* asui_settings_icon.gif*

echo "Gimp:"
echo "  image -> mode -> RGB"
echo "  change asui_settings bar to #6a73ed"
echo "  filters -> blur"
